@@ -41,9 +41,14 @@ class ValidationLog(object):
             full_path = self.get_log_path()
         self.content = self._get_content(full_path)
         self.name = os.path.splitext(os.path.basename(full_path))[0]
+        # if we have a log file then extract uuid, validation_id and timestamp
         if logfile:
-            self.uuid, self.validation_id, self.datetime = \
-                self.name.replace('.{}'.format(self.extension), '').split('_')
+            try:
+                self.uuid, _name = self.name.split('_', 1)
+                self.validation_id, self.datetime = _name.rsplit('_', 1)
+            except ValueError:
+                logging.warning('Wrong log file format, it should be formed '
+                                'such as {uuid}_{validation-id}_{timestamp}')
 
     def _get_content(self, file):
         try:
@@ -52,6 +57,9 @@ class ValidationLog(object):
         except IOError:
             msg = "log file: {} not found".format(file)
             raise IOError(msg)
+        except ValueError:
+            msg = "bad json format for {}".format(file)
+            raise ValueError(msg)
 
     def get_log_path(self):
         """Return full path of a validation log"""
@@ -60,6 +68,11 @@ class ValidationLog(object):
                                                 self.uuid, self.validation_id,
                                                 self.extension))[0]
 
+    def is_valid_format(self):
+        """ Return True if the log file is a valid validation format """
+        validation_keys = ['stats', 'validation_output', 'plays']
+        return bool(set(validation_keys).intersection(self.content.keys()))
+
     @property
     def get_logfile_infos(self):
         """
@@ -126,14 +139,16 @@ class ValidationLog(object):
     @property
     def get_duration(self):
         """Return duration of Ansible runtime"""
-        return ', '.join([play['play']['duration'].get('time_elapsed') for
-                          play in self.content['plays']])
+        duration = [play['play']['duration'].get('time_elapsed') for
+                    play in self.content['plays']]
+        return ', '.join(filter(None, duration))
 
     @property
     def get_start_time(self):
         """Return Ansible  start time"""
-        return ', '.join([play['play']['duration'].get('start') for
-                          play in self.content['plays']])
+        start_time = [play['play']['duration'].get('start') for
+                      play in self.content['plays']]
+        return ', '.join(filter(None, start_time))
 
 
 class ValidationLogs(object):
@@ -157,7 +172,7 @@ class ValidationLogs(object):
         """Return logfiles content by validation_id"""
         log_files = glob.glob("{}/*_{}_*".format(self.logs_path,
                                                  validation_id))
-        return [self._get_content(l) for l in log_files]
+        return [self._get_content(log) for log in log_files]
 
     def get_logfile_by_uuid(self, uuid):
         """Return logfiles by uuid"""
@@ -166,7 +181,7 @@ class ValidationLogs(object):
     def get_logfile_content_by_uuid(self, uuid):
         """Return logfiles content by uuid"""
         log_files = glob.glob("{}/{}_*".format(self.logs_path, uuid))
-        return [self._get_content(l) for l in log_files]
+        return [self._get_content(log) for log in log_files]
 
     def get_logfile_by_uuid_validation_id(self, uuid, validation_id):
         """Return logfiles by uuid"""
@@ -177,12 +192,13 @@ class ValidationLogs(object):
         """Return logfiles content filter by uuid and content"""
         log_files = glob.glob("{}/{}_{}_*".format(self.logs_path, uuid,
                                                   validation_id))
-        return [self._get_content(l) for l in log_files]
+        return [self._get_content(log) for log in log_files]
 
-    def get_all_logfiles(self):
+    def get_all_logfiles(self, extension='json'):
         """Return logfiles from logs_path"""
         return [join(self.logs_path, f) for f in os.listdir(self.logs_path) if
-                os.path.isfile(join(self.logs_path, f))]
+                os.path.isfile(join(self.logs_path, f)) and
+                extension in os.path.splitext(join(self.logs_path, f))[1]]
 
     def get_all_logfiles_content(self):
         """Return logfiles content filter by uuid and content"""
@@ -203,13 +219,13 @@ class ValidationLogs(object):
         passed_number = 0
         last_execution = None
         dates = []
-        for l in logs:
-            if l.get('validation_output'):
+        for log in logs:
+            if log.get('validation_output'):
                 failed_number += 1
             else:
                 passed_number += 1
             date_time = \
-                l['plays'][0]['play']['duration'].get('start').split('T')
+                log['plays'][0]['play']['duration'].get('start').split('T')
             date_start = date_time[0]
             time_start = date_time[1].split('Z')[0]
             newdate = \
@@ -230,13 +246,24 @@ class ValidationLogs(object):
             Return a list of validation results by uuid
             Can be filter by validation_id
         """
-        results = (self.get_logfile_by_uuid_validation_id(uuid,
-                                                          validation_id)
-                   if validation_id else self.get_logfile_by_uuid(uuid))
-        data = {}
+        if isinstance(uuid, list):
+            results = []
+            for id in uuid:
+                results.extend(self.get_logfile_by_uuid_validation_id(
+                    id,
+                    validation_id)
+                               if validation_id else
+                               self.get_logfile_by_uuid(id))
+        elif isinstance(uuid, str):
+            results = (self.get_logfile_by_uuid_validation_id(uuid,
+                                                              validation_id)
+                       if validation_id else self.get_logfile_by_uuid(uuid))
+        else:
+            raise RuntimeError("uuid should be either a str or a list")
         res = []
         for result in results:
             vlog = ValidationLog(logfile=result)
+            data = {}
             data['UUID'] = vlog.get_uuid
             data['Validations'] = vlog.get_validation_id
             data['Status'] = vlog.get_status
